@@ -530,6 +530,21 @@ the entirety of the docstring just like that"""
     assert not func.z.tooltip
 
 
+def test_bad_param_name_in_docstring():
+    @magicgui
+    def func(x: int):
+        """Do a little thing.
+
+        Parameters
+        ----------
+        not_x: int
+            DESCRIPTION.
+        """
+        return x
+
+    assert not func.x.tooltip
+
+
 def test_duplicated_and_missing_params_from_numpydoc():
     """Test that numpydocs docstrings can be used for tooltips."""
 
@@ -636,7 +651,6 @@ def test_magicgui_type_error():
         magicgui("not a function")  # type: ignore
 
 
-@magicgui
 def self_referencing_function(x: int = 1):
     """Function that refers to itself, and wants the FunctionGui instance."""
     return self_referencing_function
@@ -644,8 +658,10 @@ def self_referencing_function(x: int = 1):
 
 def test_magicgui_self_reference():
     """Test that self-referential magicguis work in global scopes."""
-
-    assert isinstance(self_referencing_function(), widgets.FunctionGui)
+    global self_referencing_function
+    f = magicgui(self_referencing_function)
+    assert isinstance(f(), widgets.FunctionGui)
+    assert f() is f
 
 
 def test_local_magicgui_self_reference():
@@ -726,3 +742,46 @@ def test_update_on_call():
     assert test.a.value == 10
     assert test.y.value == "b"
     assert test.call_count == 1
+
+
+def test_partial():
+    from functools import partial
+
+    def some_func(x: int, y: str) -> str:
+        return y + str(x)
+
+    wdg = magicgui(partial(some_func, 1))
+    assert len(wdg) == 2  # because of the call_button
+    assert isinstance(wdg.y, widgets.LineEdit)
+    assert not hasattr(wdg, "x")
+    assert wdg("sdf") == "sdf1"
+    assert wdg._callable_name == "some_func"
+
+    wdg2 = magicgui(partial(some_func, y="sdf"))
+    assert len(wdg2) == 3  # keyword arguments don't change the partial signature
+    assert isinstance(wdg2.x, widgets.SpinBox)
+    assert isinstance(wdg.y, widgets.LineEdit)
+    assert wdg2.y.value == "sdf"
+    assert wdg2(1) == "sdf1"
+
+
+def test_curry():
+    import toolz as tz
+
+    @tz.curry
+    def some_func2(x: int, y: str) -> str:
+        return y + str(x)
+
+    wdg = magicgui(some_func2(1))
+    assert len(wdg) == 2  # because of the call_button
+    assert isinstance(wdg.y, widgets.LineEdit)
+    assert not hasattr(wdg, "x")
+    assert wdg("sdf") == "sdf1"
+    assert wdg._callable_name == "some_func2"
+
+    wdg2 = magicgui(some_func2(y="sdf"))
+    assert len(wdg2) == 3  # keyword arguments don't change the partial signature
+    assert isinstance(wdg2.x, widgets.SpinBox)
+    assert isinstance(wdg.y, widgets.LineEdit)
+    assert wdg2.y.value == "sdf"
+    assert wdg2(1) == "sdf1"
