@@ -672,3 +672,55 @@ def test_tracking():
     assert slider.tracking is False
     slider.tracking = True
     assert slider.tracking
+
+
+def test_select_set_value():
+    sel = widgets.Select(value=[1, 3, 4], choices=list(range(10)))
+    assert sel.value == [1, 3, 4]
+    sel.value = [1, 4, 8]
+    assert sel.value == [1, 4, 8]
+
+
+def test_slider_readeout():
+    """Test that the slider readout spinbox visibility works."""
+    # FIXME: ugly direct backend access.
+    sld = widgets.Slider()
+    sld.show()
+    backend_slider = sld.native.children()[1]
+    assert "QSpinBox" in type(backend_slider).__name__
+    assert backend_slider.isVisible()
+
+    sld = widgets.Slider(readout=False)
+    sld.show()
+    backend_slider = sld.native.children()[1]
+    assert not backend_slider.isVisible()
+
+    sld = widgets.Slider(readout=True)
+    sld.show()
+    assert sld.native.children()[1].isVisible()
+    sld.readout = False
+    assert not sld.native.children()[1].isVisible()
+
+
+def test_slice_edit_events():
+    """Test that changed events of spin boxes inside a slice edit are
+    observable from its parent."""
+    start, stop, step = 0, 10, 1
+    sl = widgets.SliceEdit(start, stop, step)
+    container = widgets.Container(widgets=[sl])
+    mock = MagicMock()
+    container.changed.connect(mock)
+    sl.start.changed.emit(sl.value)
+    mock.assert_called()
+    assert sl.value == slice(start, stop, step)
+
+
+def test_pushbutton_cick_signal():
+    btn = widgets.PushButton(text="click me")
+    mock = MagicMock()
+    mock2 = MagicMock()
+    btn.changed.connect(mock)
+    btn.clicked.connect(mock2)
+    btn.native.click()
+    mock.assert_called_once()
+    mock2.assert_called_once()
